durationtools.Duration
======================

.. inheritance-diagram:: abjad.tools.durationtools.Duration.Duration.Duration
   :private-bases:

.. autoclass:: abjad.tools.durationtools.Duration.Duration.Duration

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.denominator

   .. note:: Inherited from `fractions.Fraction`

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.imag

   .. note:: Inherited from `numbers.Real`

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.numerator

   .. note:: Inherited from `fractions.Fraction`

.. autoattribute:: abjad.tools.durationtools.Duration.Duration.Duration.real

   .. note:: Inherited from `numbers.Real`

Methods
-------

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.conjugate

   .. note:: Inherited from `numbers.Real`

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.limit_denominator

   .. note:: Inherited from `fractions.Fraction`

Special Methods
---------------

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__abs__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__add__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__complex__

   .. note:: Inherited from `numbers.Real`

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__div__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__divmod__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__eq__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__float__

   .. note:: Inherited from `numbers.Rational`

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__floordiv__

   .. note:: Inherited from `fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__ge__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__gt__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__hash__

   .. note:: Inherited from `fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__le__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__lt__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__mod__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__mul__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__ne__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__neg__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__nonzero__

   .. note:: Inherited from `fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__pos__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__pow__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__radd__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rdiv__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rdivmod__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__repr__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rfloordiv__

   .. note:: Inherited from `fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rmod__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rmul__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rpow__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rsub__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__rtruediv__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__str__

   .. note:: Inherited from `fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__sub__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__truediv__

.. automethod:: abjad.tools.durationtools.Duration.Duration.Duration.__trunc__

   .. note:: Inherited from `fractions.Fraction`
